#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_yoga_1 = require("graphql-yoga");
require("reflect-metadata");
const api_1 = require("./api");
const result_handler_api_1 = require("./services/result-handler-api");
const path_1 = require("path");
const get_port_1 = require("get-port");
const parseArgs = require("minimist");
const chromeLauncher = require("chrome-launcher");
const opn = require("opn");
api_1.getSchema().then((schema) => {
    const server = new graphql_yoga_1.GraphQLServer({ schema });
    server.express.get("/", (req, res) => res.sendFile("./ui/index.html", {
        root: path_1.resolve(__dirname, "..")
    }));
    server.express.get("/ui.bundle.js", (req, res) => res.sendFile("./ui/ui.bundle.js", {
        root: path_1.resolve(__dirname, "..")
    }));
    result_handler_api_1.default(server.express);
    get_port_1.default({ port: 4000 }).then(port => {
        server.start({
            port,
            playground: "/debug"
        }, () => {
            const url = `http://localhost:${port}`;
            console.log(`🍡  Majestic is running: ${url} `);
            const args = parseArgs(process.argv);
            if (args.app) {
                chromeLauncher
                    .launch({
                    startingUrl: url,
                    chromeFlags: [`--app=${url}`]
                })
                    .then((chrome) => {
                    console.log("Opening app");
                });
            }
            else {
                opn(url);
            }
        });
    });
});
//# sourceMappingURL=index.js.map