"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const path_1 = require("path");
const event_emitter_1 = require("../../event-emitter");
exports.RunnerEvents = {
    RUNNER_STARTED: "RunnerStarted",
    RUNNER_STOPPED: "RunnerStopped",
    RUNNER_WATCH_MODE_CHANGE: "WatchModeChanged",
    RUNNER_ACTIVE_FILE_CHANGE: "RunnerActiveFileChange"
};
class JestManager {
    constructor(project, config) {
        this.project = project;
        this.config = config;
    }
    run(watch) {
        this.executeJest(["--reporters", this.getRepoterPath(), ...(watch ? ["--watch"] : [])], true);
    }
    runSingleFile(path, watch) {
        this.executeJest([
            this.getPatternForPath(path),
            ...(watch ? ["--watch"] : []),
            "--reporters",
            "default",
            this.getRepoterPath()
        ], !watch // while watching, can not inherit stdio because we want to write back and interact with the process
        );
    }
    updateSnapshotToFile(path) {
        this.executeJest([
            this.getPatternForPath(path),
            "-u",
            "--reporters",
            this.getRepoterPath()
        ]);
    }
    switchToAnotherFile(path) {
        this.executeInSequence([
            {
                fn: () => this.process.stdin && this.process.stdin.write("p"),
                delay: 0
            },
            {
                fn: () => this.process.stdin &&
                    this.process.stdin.write(this.getPatternForPath(path)),
                delay: 100
            },
            {
                fn: () => this.process.stdin &&
                    this.process.stdin.write(new Buffer("0d", "hex").toString()),
                delay: 200
            }
        ]);
    }
    executeJest(args = [], inherit = false) {
        this.reportStart();
        this.process = child_process_1.spawn(`node -r ${this.getPatchFilePath()} ${this.config.jestScriptPath}`, [...args, ...(this.config.args || [])], {
            cwd: this.project.projectRoot,
            shell: true,
            stdio: inherit ? "inherit" : "pipe",
            env: Object.assign({}, (this.config.env || {}))
        });
        this.process.on("exit", () => {
            this.reportStop();
        });
        this.process.stdout &&
            this.process.stdout.on("data", (data) => {
                console.log(data.toString().trim());
            });
        this.process.stderr &&
            this.process.stderr.on("data", (data) => {
                console.log(data.toString().trim());
            });
    }
    getRepoterPath() {
        return path_1.join(__dirname, "./scripts/reporter.js");
    }
    getPatchFilePath() {
        return path_1.join(__dirname, "./scripts/patch.js");
    }
    getPatternForPath(path) {
        let replacePattern = /\//g;
        if (process.platform === "win32") {
            replacePattern = /\\/g;
        }
        return `^${path.replace(replacePattern, ".")}$`;
    }
    reportStart() {
        event_emitter_1.pubsub.publish(exports.RunnerEvents.RUNNER_STARTED, {
            id: exports.RunnerEvents.RUNNER_STARTED,
            payload: {
                isRunning: true
            }
        });
    }
    stop() {
        if (this.process) {
            this.process.kill();
            this.reportStop();
        }
    }
    reportStop() {
        event_emitter_1.pubsub.publish(exports.RunnerEvents.RUNNER_STOPPED, {
            id: exports.RunnerEvents.RUNNER_STOPPED,
            payload: {
                isRunning: false
            }
        });
    }
    executeInSequence(funcs) {
        return __awaiter(this, void 0, void 0, function* () {
            for (const { fn, delay } of funcs) {
                yield this.setTimeoutPromisify(fn, delay);
            }
        });
    }
    setTimeoutPromisify(fn, delay) {
        return new Promise(resolve => {
            setTimeout(() => {
                fn();
                resolve();
            }, delay);
        });
    }
}
exports.default = JestManager;
//# sourceMappingURL=index.js.map