"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const micromatch = require("micromatch");
const pathUtil = require("path");
const { escapePathForRegex } = require("jest-regex-util");
const globsToMatcher = (globs) => {
    if (globs == null || globs.length === 0 || global === undefined) {
        return () => true;
    }
    const matchers = globs.map(each => micromatch.matcher(each, { dot: true }));
    return (path) => {
        return matchers.some(each => each(path));
    };
};
const regexToMatcher = (testRegex) => {
    if (!testRegex) {
        return () => true;
    }
    const regex = new RegExp(testRegex);
    return (path) => regex.test(path);
};
class TestFileMatcher {
    constructor(projectRoot, config) {
        this._rootPattern = new RegExp(([projectRoot] || [])
            .map((dir) => escapePathForRegex(dir + pathUtil.sep))
            .join("|"));
        const ignorePattern = []; // TODO
        this._testIgnorePattern = ignorePattern.length
            ? new RegExp(ignorePattern.join("|"))
            : undefined;
        this._testPathCases = {
            testMatch: globsToMatcher(config.testMatch),
            testPathIgnorePatterns: path => !this._testIgnorePattern || !this._testIgnorePattern.test(path),
            testRegex: regexToMatcher(config.testRegex || "")
        };
    }
    isTestFilePath(path) {
        return Object.keys(this._testPathCases).every(key => this._testPathCases[key](path));
    }
}
function getTestPatternsMatcher(root, majesticConfig) {
    const fileSearcher = new TestFileMatcher(root, majesticConfig);
    return (path) => {
        const result = fileSearcher.isTestFilePath(path);
        return result;
    };
}
exports.getTestPatternsMatcher = getTestPatternsMatcher;
//# sourceMappingURL=test-file-matcher.js.map